@@ -22,6 +22,13 @@ has uri => (
     required => 1,
     );
 
+has namespace => (
+    is => 'rw',
+    isa => 'Str',
+    required => 0,
+    default => '',
+    );
+
 has method => (
     is => 'rw',
     isa => 'Str',
@@ -258,6 +265,10 @@ sub _soap_call {
         $client->on_action( sub { join('/', @_) } );
     }
 
+    if (my $ns = $self->namespace()) {
+        $client->ns($ns);
+    }
+
     my @params = $self->_make_head();
     push @params, $self->_make_params( \@args );
 
